==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/xml/classes/xmlelementotazkahodnoceni.php <==
<?php
/**
 * stanislav.elbl, 09.06.2021 21:40
 */

namespace RonPortal\XML\Classes;

use Ron\GuiUtils;
use Ron\Personalistika\OtazkaDotazniku;
use RonPortal\XML\XMLFormElement;

class XMLElementOtazkaHodnoceni extends XMLFormElement
{
    function getHTMLOutput()
    {
        $id = (int)$this->nahradPromenne($this ->getAttributeValue('id'));
        $druhHodnoceni = (int)$this->nahradPromenne($this ->getAttributeValue('druhhodnoceni'));
        $temaCislo = (int)$this->nahradPromenne($this ->getAttributeValue('temacislo'));
        $kodKriteria = $this->nahradPromenne($this ->getAttributeValue('kodkriteria'));

        $otazka = null;

        if ($druhHodnoceni == $this ->xmlForm ->dotaznik ->druhHodnoceni  &&  $temaCislo == $this ->xmlForm ->dotaznik ->temaCislo) {
            $otazka = $this ->xmlForm ->dotaznik ->vratOtazku($kodKriteria);
        }

        if (!$otazka) {
            $otazka = new OtazkaDotazniku($id, $druhHodnoceni, $temaCislo);
            $otazka->nactiOtazku($this ->xmlForm ->database, $kodKriteria);
        }

        $zpusobZobrazeni = $this ->getAttributeValue('zpusobzobrazeni');
        if (!is_null($zpusobZobrazeni) && ($zpusobZobrazeni !== '')) {
            $otazka -> zpusobZobrazeni = $zpusobZobrazeni;
        }

        $styleStr = ($otazka->barvaPozadi)
            ? 'style="background-color:' . GuiUtils::getHtmlColor($otazka->barvaPozadi) . '"'
            : '';

        $result =
            "<DIV $styleStr>".
            $otazka -> vratHTML_Otazka().
            $otazka -> vratHTML_Odpoved(!$this ->xmlForm -> readOnly).
            '</DIV>';

        if ( !$otazka ->odpovedVyplnena  &&  $otazka ->povinnaOdpoved ) {
            $this ->xmlForm -> dotaznik -> fVyplnenoVse = false;
        }

        return $result;
    }
}

/*
//DOC
PAGE otazkahodnoceni
<pre>
PRE
  <otazkahodnoceni id="id_hodnoceni" druhhodnoceni="druh_hodnoceni" temacislo="tema_cislo" kodkriteria="kodkriteria" zpusobzobrazeni="1"/>
PREEND
</pre>

//END
*/

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/xml/classes/xmlelementotazkahodnoceni.php <==
<?php
/**
 * stanislav.elbl, 09.06.2021 21:40
 */

namespace RonPortal\XML\Classes;

use Ron\GuiUtils;
use Ron\Personalistika\OtazkaDotazniku;
use RonPortal\XML\XMLFormElement;

class XMLElementOtazkaHodnoceni extends XMLFormElement
{
    function getHTMLOutput()
    {
        $id = (int)$this->nahradPromenne($this ->getAttributeValue('id'));
        $druhHodnoceni = (int)$this->nahradPromenne($this ->getAttributeValue('druhhodnoceni'));
        $temaCislo = (int)$this->nahradPromenne($this ->getAttributeValue('temacislo'));
        $kodKriteria = $this->nahradPromenne($this ->getAttributeValue('kodkriteria'));

        $otazka = null;

        if ($druhHodnoceni == $this ->xmlForm ->dotaznik ->druhHodnoceni  &&  $temaCislo == $this ->xmlForm ->dotaznik ->temaCislo) {
            $otazka = $this ->xmlForm ->dotaznik ->vratOtazku($kodKriteria);
        }

        if (!$otazka) {
            $otazka = new OtazkaDotazniku($id, $druhHodnoceni, $temaCislo);
            $otazka->nactiOtazku($this ->xmlForm ->database, $kodKriteria);
        }

        $zpusobZobrazeni = $this ->getAttributeValue('zpusobzobrazeni');
        if (!is_null($zpusobZobrazeni) && ($zpusobZobrazeni !== '')) {
            $otazka -> zpusobZobrazeni = $zpusobZobrazeni;
        }

        $styleStr = ($otazka->barvaPozadi)
            ? 'style="background-color:' . GuiUtils::getHtmlColor($otazka->barvaPozadi) . '"'
            : '';

        $result =
            "<DIV $styleStr>";

        $editace = !$this->xmlForm->readOnly;

        //zobrazi se jen otazky, ktere nejsou definovany jako skryte (definovano, bud pro konkretni uroven predavani, nebo primo pro otazku)
        if ($otazka->zobrazitOtazku !== 2)
            $result .= $otazka->vratHTML_Otazka();

        if (($otazka->zobrazitOtazku == 1) || ($otazka->zobrazitOtazku == 2))
            $editace = false;

        $result .=
            $otazka -> vratHTML_Odpoved($editace).
            '</DIV>';

        if ( !$otazka ->odpovedVyplnena  &&  $otazka ->povinnaOdpoved ) {
            $this ->xmlForm -> dotaznik -> fVyplnenoVse = false;
        }

        return $result;
    }
}

/*
//DOC
PAGE otazkahodnoceni
<pre>
PRE
  <otazkahodnoceni id="id_hodnoceni" druhhodnoceni="druh_hodnoceni" temacislo="tema_cislo" kodkriteria="kodkriteria" zpusobzobrazeni="1"/>
PREEND
</pre>

//END
*/
